@@ -527,8 +527,8 @@ addPlugin({
                     requiresFlags: ["CorePlugin.HasProjectService"],
                     order: 110,
                     type: "directoryPath",
-                    category: qsTr("Default Document Folder"),
-                    detailsText: qsTr("Directory where documents unassociated with a project will be saved."),
+                    category: qsTr("Documents Folder"),
+                    detailsText: qsTr("The folder where projects and documents will be saved."),
                 },
                 "$$.StartupBehavior": {
                     requiresFlags: ["CorePlugin.HasProjectService"],
@@ -647,7 +647,7 @@ if (AppLib.environment.windows) {
     });
 }
 
-if (AppLib.environment.has_enhanced_windowing_experience) {
+if (AppLib.environment.has_enhanced_windowing_experience_option) {
     addPlugin({
         settings: {
             "$$.Environment": {
@@ -661,6 +661,17 @@ if (AppLib.environment.has_enhanced_windowing_experience) {
                         detailsText: qsTr("Enable an enhanced windowing experience. Requires app restart."),
                         changeRequiresAppRestart: true,
                     },
+                },
+            },
+        },
+    });
+}
+
+if (AppLib.environment.has_enhanced_windowing_experience) {
+    addPlugin({
+        settings: {
+            "$$.Environment": {
+                properties: {
                     "$$.FloatingWindowsAlwaysOnTop": {
                         order: 107,
                         type: "bool",
